@@ -23,7 +23,6 @@
 
 #include <core/partition.h>
 #include <core/device.h>
-#include <core/lvmdevice.h>
 
 #include <fs/filesystemfactory.h>
 #include <fs/luks.h>
@@ -32,8 +31,8 @@
 #include <util/helpers.h>
 #include "util/guihelpers.h"
 
+#include <QtGlobal>
 #include <QFontDatabase>
-#include <QtAlgorithms>
 
 #include <KColorScheme>
 #include <KConfigGroup>
@@ -49,8 +48,7 @@
 NewDialog::NewDialog(QWidget* parent, Device& device, Partition& unallocatedPartition, PartitionRole::Roles r) :
     SizeDialogBase(parent, device, unallocatedPartition, unallocatedPartition.firstSector(), unallocatedPartition.lastSector()),
     m_PartitionRoles(r),
-    m_IsValidPassword(true),
-    m_IsValidLVName(true)
+    m_IsValidPassword(true)
 {
     setWindowTitle(xi18nc("@title:window", "Create a new partition"));
 
@@ -103,20 +101,6 @@ void NewDialog::setupDialog()
     dialogWidget().checkBoxEncrypt().hide();
     dialogWidget().editPassphrase().hide();
 
-    if (device().type() == Device::Disk_Device) {
-        dialogWidget().lvName().hide();
-        dialogWidget().textLVName().hide();
-    }
-
-    if (device().type() == Device::LVM_Device) {
-        dialogWidget().hideBeforeAndAfter();
-        detailsWidget().checkAlign().setChecked(false);
-        detailsWidget().checkAlign().setEnabled(false);
-        detailsButton->hide();
-        dialogWidget().comboFileSystem().removeItem(dialogWidget().comboFileSystem().findText(QStringLiteral("lvm2 pv")));
-        m_IsValidLVName = false;
-    }
-
     dialogWidget().editPassphrase().setMinimumPasswordLength(1);
     dialogWidget().editPassphrase().setMaximumPasswordLength(512); // cryptsetup does not support longer passwords
 
@@ -137,11 +121,10 @@ void NewDialog::setupConnections()
     connect(&dialogWidget().radioExtended(), &QRadioButton::toggled, this, &NewDialog::onRoleChanged);
     connect(&dialogWidget().radioLogical(), &QRadioButton::toggled, this, &NewDialog::onRoleChanged);
     connect(&dialogWidget().checkBoxEncrypt(), &QCheckBox::toggled, this, &NewDialog::onRoleChanged);
-    connect(&dialogWidget().comboFileSystem(), static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewDialog::onFilesystemChanged);
+    connect(&dialogWidget().comboFileSystem(), qOverload<int>(&QComboBox::currentIndexChanged), this, &NewDialog::onFilesystemChanged);
     connect(&dialogWidget().label(), &QLineEdit::textChanged, this, &NewDialog::onLabelChanged);
     // listen to password status updates
     connect(&dialogWidget().editPassphrase(), &KNewPasswordWidget::passwordStatusChanged, this, &NewDialog::slotPasswordStatusChanged);
-    connect(&dialogWidget().lvName(), &QLineEdit::textChanged, this, &NewDialog::onLVNameChanged);
 
     SizeDialogBase::setupConnections();
 }
@@ -258,20 +241,6 @@ void NewDialog::slotPasswordStatusChanged()
     updateOkButtonStatus();
 }
 
-void NewDialog::onLVNameChanged(const QString& newName)
-{
-    partition().setPartitionPath(device().deviceNode() + QStringLiteral("/") + newName.trimmed());
-    if ((dialogWidget().lvName().isVisible() &&
-        dialogWidget().lvName().text().isEmpty()) ||
-        (device().type() == Device::LVM_Device &&
-         dynamic_cast<LvmDevice&>(device()).partitionNodes().contains(partition().partitionPath())) ) {
-        m_IsValidLVName = false;
-    } else {
-        m_IsValidLVName = true;
-    }
-    updateOkButtonStatus();
-}
-
 void NewDialog::updateHideAndShow()
 {
     // this is mostly copy'n'pasted from PartPropsDialog::updateHideAndShow()
