@@ -25,6 +25,7 @@
 
 #include <core/partitiontable.h>
 #include <core/device.h>
+#include <core/lvmdevice.h>
 #include <core/partition.h>
 #include <core/partitionalignment.h>
 
@@ -36,8 +37,9 @@
 
 #include <KLocalizedString>
 
-#include <QFrame>
 #include <QDialogButtonBox>
+#include <QFrame>
+#include <QtGlobal>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -55,7 +57,8 @@ SizeDialogBase::SizeDialogBase(QWidget* parent, Device& d, Partition& part, qint
     m_MinimumFirstSector(minFirst),
     m_MaximumLastSector(maxLast),
     m_MinimumLength(-1),
-    m_MaximumLength(-1)
+    m_MaximumLength(-1),
+    m_IsValidLVName(true)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     setLayout(mainLayout);
@@ -101,6 +104,26 @@ void SizeDialogBase::setupDialog()
     else
         dialogWidget().partResizerWidget().init(device(), partition(), minimumFirstSector(), maximumLastSector(), true, canMove());
     dialogWidget().partResizerWidget().setAlign(Config::alignDefault());
+
+    if (device().type() == Device::Disk_Device) {
+        dialogWidget().lvName().hide();
+        dialogWidget().textLVName().hide();
+    }
+    if (device().type() == Device::LVM_Device) {
+        dialogWidget().hideBeforeAndAfter();
+        detailsWidget().checkAlign().setChecked(false);
+        detailsWidget().checkAlign().setEnabled(false);
+        detailsButton->hide();
+        dialogWidget().comboFileSystem().removeItem(dialogWidget().comboFileSystem().findText(QStringLiteral("lvm2 pv")));
+        m_IsValidLVName = false;
+
+        /* LVM logical volume name can consist of: letters numbers _ . - +
+         * It cannot start with underscore _ and must not be equal to . or .. or any entry in /dev/
+         * QLineEdit accepts QValidator::Intermediate, so we just disable . at the beginning */
+        QRegularExpression re(QStringLiteral(R"(^(?!_|\.)[\w\-.+]+)"));
+        QRegularExpressionValidator *validator = new QRegularExpressionValidator(re, this);
+        dialogWidget().lvName().setValidator(validator);
+    }
 }
 
 void SizeDialogBase::setupConstraints()
@@ -150,13 +173,15 @@ void SizeDialogBase::setupConnections()
     connect(&dialogWidget().partResizerWidget(), &PartResizerWidget::firstSectorChanged, this, &SizeDialogBase::onResizerWidgetFirstSectorChanged);
     connect(&dialogWidget().partResizerWidget(), &PartResizerWidget::lastSectorChanged, this, &SizeDialogBase::onResizerWidgetLastSectorChanged);
 
-    connect(&dialogWidget().spinFreeBefore(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeBeforeChanged);
-    connect(&dialogWidget().spinFreeAfter(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeAfterChanged);
-    connect(&dialogWidget().spinCapacity(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinCapacityChanged);
+    connect(&dialogWidget().spinFreeBefore(), qOverload<double>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeBeforeChanged);
+    connect(&dialogWidget().spinFreeAfter(), qOverload<double>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeAfterChanged);
+    connect(&dialogWidget().spinCapacity(), qOverload<double>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinCapacityChanged);
 
-    connect(&detailsWidget().spinFirstSector(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFirstSectorChanged);
-    connect(&detailsWidget().spinLastSector(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinLastSectorChanged);
+    connect(&detailsWidget().spinFirstSector(), qOverload<double>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFirstSectorChanged);
+    connect(&detailsWidget().spinLastSector(), qOverload<double>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinLastSectorChanged);
     connect(&detailsWidget().checkAlign(), &QCheckBox::toggled, this, &SizeDialogBase::onAlignToggled);
+
+    connect(&dialogWidget().lvName(), &QLineEdit::textChanged, this, &SizeDialogBase::onLVNameChanged);
 }
 
 void SizeDialogBase::toggleDetails()
@@ -351,6 +376,25 @@ void SizeDialogBase::onAlignToggled(bool align)
     }
 }
 
+void SizeDialogBase::onLVNameChanged(const QString& newName)
+{
+    partition().setPartitionPath(device().deviceNode() + QStringLiteral("/") + newName.trimmed());
+    if ((dialogWidget().lvName().isVisible() &&
+        dialogWidget().lvName().text().isEmpty()) ||
+        (device().type() == Device::LVM_Device &&
+         dynamic_cast<LvmDevice&>(device()).partitionNodes().contains(partition().partitionPath())) ) {
+        m_IsValidLVName = false;
+    } else {
+        m_IsValidLVName = true;
+    }
+    updateOkButtonStatus();
+}
+
+void SizeDialogBase::updateOkButtonStatus()
+{
+    okButton->setEnabled(isValidLVName());
+}
+
 void SizeDialogBase::updateSpinFreeBefore(qint64 sectorsFreeBefore)
 {
     const bool signalState = dialogWidget().spinFreeBefore().blockSignals(true);
